@@ -417,12 +417,19 @@ pub fn event_state() -> Shortcut {
 pub fn screen_size() -> (f64, f64) {
     unsafe {
         (
-            (fl::Fl_screen_w() as f64 / 0.96),
-            (fl::Fl_screen_h() as f64 / 0.96),
+            (fl::Fl_screen_w() as f64),
+            (fl::Fl_screen_h() as f64),
         )
     }
 }
 
+/// Returns a pair of the x & y coords of the screen
+pub fn screen_coords() -> (i32, i32) {
+    unsafe {
+        (fl::Fl_screen_x(), fl::Fl_screen_y())
+    }
+}
+
 /// Used for widgets implementing the `InputExt`, pastes content from the clipboard
 pub fn paste<T>(widget: &T)
 where
@@ -1322,6 +1329,49 @@ pub fn screen_count() -> i32 {
     unsafe { fl::Fl_screen_count() as i32 }
 }
 
+/// Get the screen number based on its coordinates
+pub fn screen_num(x: i32, y: i32) -> i32 {
+    unsafe {
+        fl::Fl_screen_num(x, y)
+    }
+}
+
+/// Get a screen's dpi resolution
+/// # Returns
+/// (vertical, horizontal) resolutions
+pub fn screen_dpi(screen_num: i32) -> (f32, f32) {
+    let mut h: f32 = 0.;
+    let mut v: f32 = 0.;
+    unsafe {
+        fl::Fl_screen_dpi(&mut h, &mut v, screen_num);
+    }
+    (h, v)
+}
+
+/// Get a screen's xywh
+pub fn screen_xywh(screen_num: i32) -> (i32, i32, i32, i32) {
+    let mut x = 0;
+    let mut y = 0;
+    let mut w = 0;
+    let mut h = 0;
+    unsafe {
+        fl::Fl_screen_xywh(&mut x, &mut y, &mut w, &mut h, screen_num);
+    }
+    (x, y, w, h)
+}
+
+/// Get a screen's working area
+pub fn screen_work_area(screen_num: i32) -> (i32, i32, i32, i32) {
+    let mut x = 0;
+    let mut y = 0;
+    let mut w = 0;
+    let mut h = 0;
+    unsafe {
+        fl::Fl_screen_work_area(&mut x, &mut y, &mut w, &mut h, screen_num);
+    }
+    (x, y, w, h)
+}
+
 /// Open the current display
 /// # Safety
 /// A correct visual must be set prior to opening the display
